{% extends "registration/registration_base.html" %}
{% load url from future %}
{% load i18n %}

{% block masthead %}
<h2>{% trans "Password change" %}</h2>
{% endblock %}

{% block content %}
<p>{% trans "Please enter your old password, then enter your new password twice." %}</p>
<form method="post" action=".">
    {% csrf_token %}
    {{ form.non_field_errors }}
    {% for field in form %}
        <div class="fieldWrapper">
            {{ field.errors }}
            {{ field.label_tag }}
            {{ field }}
        </div>
    {% endfor %}
    <input type="submit" value="{% trans "Save" %}">
    <div><a href="{% url "auth_password_reset" %}">{% trans "Reset password" %}</a></div>
</form>
{% endblock %}
