{% extends "registration/registration_base.html" %}
{% load url from future %}
{% load i18n %}

{% block masthead %}
<h2>{% trans "Password reset complete" %}</h2>
{% endblock %}

{% block content %}
<p>{% trans "Please login with your new password." %}</p>
<a href="{% url "auth_login" %}">{% trans "Login" %}</a>
{% endblock %}
