{% extends "registration/registration_base.html" %}
{% load url from future %}
{% load i18n %}

{% block masthead %}
<h2>{% trans "Activation complete" %}</h2>
{% endblock %}

{% block content %}
<p>{% trans "You may now login with your username and password." %}</p>
{% if not user.is_authenticated %}
    <a href="{% url "auth_login" %}">{% trans "Login now" %}</a>
{% else %}
    <a href="/">{% trans "Home" %}</a>
{% endif %}
{% endblock %}
