{% extends "registration/registration_base.html" %}
{% load url from future %}
{% load i18n %}

{% block masthead %}
<h2>{% trans "Registration form" %}</h2>
{% endblock %}

{% block content %}
<form method="post" action=".">
    {% csrf_token %}
    {{ form.non_field_errors }}
    {% for field in form %}
    <div class="fieldWrapper">
        {{ field.errors }}
        {{ field.label_tag }}
        {{ field }}
    </div>
    {% endfor %}
    <input type="submit" value="{% trans "Register" %}">
</form>
{% endblock %}
