{% extends "registration/registration_base.html" %}
{% load i18n %}

{% block masthead %}
<h2>{% trans "Password reset" %}</h2>
{% endblock %}

{% block content %}
<p>{% trans "Enter your e-mail address below, and we will send instructions for setting a new one." %}</p>
<form action="." method="post">
    {% csrf_token %}
    {{ form.non_field_errors }}
    {% for field in form %}
        <div class="fieldWrapper">
            {{ field.errors }}
            {{ field.label_tag }}
            {{ field }}
        </div>
    {% endfor %}
    <input type="submit" value="{% trans "Reset password" %}" />
</form>
{% endblock %}
