{% extends "registration/registration_base.html" %}
{% load url from future %}
{% load i18n %}

{% block masthead %}
<h1>{% trans "Registration closed" %}</h1>
{% endblock %}

{% block content %}
<p>{% trans "We are sorry but registration is temporarily closed." %}</p>
<p>{% trans "Please come back shortly and try again. We apologize for the inconvenience." %}</p>
{% endblock %}
