{% extends "registration/registration_base.html" %}
{% load url from future %}
{% load i18n %}

{% block masthead %}
<h2>{% trans "Password reset successful" %}</h2>
{% endblock %}

{% block content %}
<p>{% trans "We have sent you instructions for setting your password." %}</p>
{% endblock %}
